import type { CountryCode, ShippingPriceData, StateCode } from '@uppfirst/geo-shipping-prices/types/Shipping';
import type { Decimal } from 'decimal.js';
export interface ReservePricing {
    base: number;
    traitCost: number;
    taxCost: number;
    taxPercent: number;
    shippingCost: number;
    total: number;
    gainedRewardsAmount: number;
}
export interface Pricing {
    currency: Currency;
    usedRewardsTotal: number;
    startAmountPercent: number;
    reserve: ReservePricing;
    claim: {
        base: number;
        total: number;
        gainedRewardsAmount: number;
    };
    total: {
        base: number;
        total: number;
        gainedRewardsAmount: number;
    };
}
export interface Currency {
    code: string;
    symbol: string;
    decimals: number;
}
export interface BaseProduct {
    price: number | Decimal;
    startAmountPercent: number | Decimal;
    rewardShare: number | Decimal;
    currency: {
        decimals: number | Decimal;
        symbol: string;
    };
    shipping?: ShippingPriceData;
}
export interface TraitCombination {
    price: number | Decimal;
}
export interface Reward {
    worth: number | Decimal;
}
export interface CalculateArgs {
    product: BaseProduct;
    combination?: TraitCombination;
    usedRewardsReserve?: Reward[];
    usedRewardsClaim?: Reward[];
    countryCode?: CountryCode;
    stateCode?: StateCode;
}
/**
 * Options for the calculate function.
 */
export interface CalculateOpts {
    returnSmallestUnit?: boolean;
}
